summaryrefslogtreecommitdiff
path: root/gdk/gdkdevice.h
diff options
context:
space:
mode:
authorAlexander Larsson <alexl@redhat.com>2018-03-20 16:16:57 +0000
committerAlexander Larsson <alexl@redhat.com>2018-03-20 16:16:57 +0000
commit695d141f32d8aed14b57cc065554974d541f8ba6 (patch)
treedeb13486e9441d4be37b882b13013ac98d936d42 /gdk/gdkdevice.h
parentb83ba41f2d129953572e3ad8d490b4d3e5a7ddf9 (diff)
parent4ac450b324bcae047d3fa53986133e18da0ec1bf (diff)
downloadgtk+-695d141f32d8aed14b57cc065554974d541f8ba6.tar.gz
Merge branch 'rename-window-to-surface' into 'master'
Rename window to surface See merge request GNOME/gtk!72
Diffstat (limited to 'gdk/gdkdevice.h')
-rw-r--r--gdk/gdkdevice.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/gdk/gdkdevice.h b/gdk/gdkdevice.h
index bddaa71824..c52ddababa 100644
--- a/gdk/gdkdevice.h
+++ b/gdk/gdkdevice.h
@@ -73,10 +73,10 @@ typedef enum
* @GDK_MODE_DISABLED: the device is disabled and will not report any events.
* @GDK_MODE_SCREEN: the device is enabled. The device’s coordinate space
* maps to the entire screen.
* @GDK_MODE_WINDOW: the device is enabled. The device’s coordinate space
* is mapped to a single window. The manner in which this window
* is chosen is undefined, but it will typically be the same
* way in which the focus window for key events is determined.
*
* An enumeration that describes the mode of an input device.
*/
@@ -84,7 +84,7 @@ typedef enum
{
GDK_MODE_DISABLED,
GDK_MODE_SCREEN,
- GDK_MODE_WINDOW
+ GDK_MODE_SURFACE
} GdkInputMode;
/**
@@ -163,7 +163,7 @@ void gdk_device_set_axis_use (GdkDevice *device,
GDK_AVAILABLE_IN_ALL
void gdk_device_get_state (GdkDevice *device,
- GdkWindow *window,
+ GdkSurface *surface,
gdouble *axes,
GdkModifierType *mask);
GDK_AVAILABLE_IN_ALL
@@ -171,8 +171,8 @@ void gdk_device_get_position (GdkDevice *device,
gint *x,
gint *y);
GDK_AVAILABLE_IN_ALL
-GdkWindow *
- gdk_device_get_window_at_position
+GdkSurface *
+ gdk_device_get_surface_at_position
(GdkDevice *device,
gint *win_x,
gint *win_y);
@@ -181,14 +181,14 @@ void gdk_device_get_position_double (GdkDevice *device,
gdouble *x,
gdouble *y);
GDK_AVAILABLE_IN_ALL
-GdkWindow *
- gdk_device_get_window_at_position_double
+GdkSurface *
+ gdk_device_get_surface_at_position_double
(GdkDevice *device,
gdouble *win_x,
gdouble *win_y);
GDK_AVAILABLE_IN_ALL
gboolean gdk_device_get_history (GdkDevice *device,
- GdkWindow *window,
+ GdkSurface *surface,
guint32 start,
guint32 stop,
GdkTimeCoord ***events,
@@ -225,7 +225,7 @@ GdkDeviceType gdk_device_get_device_type (GdkDevice *device);
GDK_DEPRECATED_FOR(gdk_seat_grab)
GdkGrabStatus gdk_device_grab (GdkDevice *device,
- GdkWindow *window,
+ GdkSurface *surface,
GdkGrabOwnership grab_ownership,
gboolean owner_events,
GdkEventMask event_mask,
@@ -242,7 +242,7 @@ void gdk_device_warp (GdkDevice *device,
gint y);
GDK_AVAILABLE_IN_ALL
-GdkWindow *gdk_device_get_last_event_window (GdkDevice *device);
+GdkSurface *gdk_device_get_last_event_surface (GdkDevice *device);
GDK_AVAILABLE_IN_ALL
const gchar *gdk_device_get_vendor_id (GdkDevice *device);
@@ -73,10 +73,10 @@ typedef enum
* @GDK_MODE_SCREEN: the device is enabled. The device’s coordinate space
* maps to the entire screen.
- * @GDK_MODE_WINDOW: the device is enabled. The device’s coordinate space
- * is mapped to a single window. The manner in which this window
+ * @GDK_MODE_SURFACE: the device is enabled. The device’s coordinate space
+ * is mapped to a single surface. The manner in which this surface
* is chosen is undefined, but it will typically be the same
@@ -73,10 +73,10 @@ typedef enum
* is chosen is undefined, but it will typically be the same
- * way in which the focus window for key events is determined.
+ * way in which the focus surface for key events is determined.
*
* An enumeration that describes the mode of an input device.